@@ -174,13 +174,16 @@ class EcoVacsIOTMQ(ClientMQTT):
 
         headers = {'User-Agent': 'Dalvik/2.1.0 (Linux; U; Android 5.1.1; A5010 Build/LMY48Z)',}
         url = (self.portal_url_format + "/iot/devmanager.do?mid=" + params['toType'] + "&did=" + params['toId'] + "&td=" + params['td'] + "&u=" + params['auth']['userid'] + "&cv=1.67.3&t=a&av=1.3.1").format(continent=self.continent)
+        
+        try:  
+            with requests.post(url, headers=headers, json=params, timeout=20, verify=verify_ssl) as response:
+                data = response.json()
+                if response.status_code != 200:
+                    _LOGGER.warning("Error calling API " + str(url))
 
-        with requests.post(url, headers=headers, json=params, timeout=20, verify=verify_ssl) as response:
-            data = response.json()
-            if response.status_code != 200:
-                _LOGGER.warning("Error calling API " + str(url))
-
-            return data
+                return data
+        except:
+            return {}
             
     def CallCleanLogsApi(self, args, verify_ssl=True):
         params = {}
@@ -189,12 +192,15 @@ class EcoVacsIOTMQ(ClientMQTT):
         headers = {'User-Agent': 'Dalvik/2.1.0 (Linux; U; Android 5.1.1; A5010 Build/LMY48Z)',}
         url = (self.portal_url_format + "/lg/log.do?td=" + params['td'] + "&u=" + params['auth']['userid'] + "&cv=1.67.3&t=a&av=1.3.1").format(continent=self.continent)
 
-        with requests.post(url, headers=headers, json=params, timeout=20, verify=verify_ssl) as response:
-            data = response.json()
-            if response.status_code != 200:
-                _LOGGER.warning("Error calling API " + str(url))
+        try:
+            with requests.post(url, headers=headers, json=params, timeout=20, verify=verify_ssl) as response:
+                data = response.json()
+                if response.status_code != 200:
+                    _LOGGER.warning("Error calling API " + str(url))
 
-            return data
+                return data
+        except:
+            return {}
 
     def _handle_ctl_api(self, action, message):
         if not message == {}:
